Learn R Programming

inventorize (version 1.0.3)

linear_elasticity: linear_elasticity

Description

calculating elasticity of a linear price response function

Usage

linear_elasticity(prices, Sales, present_price, cost_of_product)

Arguments

prices

vector of prices.

Sales

Vector of sales against each price .

present_price

numeric, present price of the product .

cost_of_product

cost of the product, if the product/service has no cost ,then cost is set to zero.

Value

the elasticity at the present price , the price for optimum revenue and thee price for optimum cost.

Details

This function is helpful to determine if your product is elastic or not based on a linear price response function. if product demand is not linear to price, try using the single product optimization function instead. The price elasticity of demand which is often shortened to demand elasticity is defined to be the percentage change in quantity demanded, q, divided by the percentage change in price, p. When |E| > 1, we say the good is price elastic.In this case, change in price, there is a greater than 1 change in quantity demanded.In this case, management should decrease price to have a higher revenue. When |E| < 1, we say the good is price inelastic.In this case, for a 1 in quantity demanded.In this case, management should increase price to have a higher revenue. When |E| = 1, we say the good is price unit elastic.In this case, and so, for a 1 there is also an 1 This is the optimal price which means it maximizes revenue.

Examples

Run this code
# NOT RUN {
linear_elasticity(prices=c(5,10,8,5,14),
Sales= c(450,400,420,450,360),
present_price=15,cost_of_product=40)
# }

Run the code above in your browser using DataLab