Identyfing ABC category based on the pareto rule for both demand and selling price,a mix of nine categories are produced.
Identyfing ABC category based on the pareto rule.A category is up to 80
Usage
productmix(SKUs, sales, revenue, na.rm = TRUE)
Arguments
SKUs,
charachter, a vector of SKU names.
sales,
vector, a vector of items sold per sku, should be the same number of rows as SKU.
revenue
price vector, a vector of total revenu per sku, should be the same number of rows as SKU.
na.rm
, logical and by default is TRUE
Value
a dataframe that contains ABC categories with a bar plot of the count of items in each category.