cost of the product, if the product/service has no cost ,then cost is set to zero.
Value
the elasticity at the present price , the price for optimum revenue and thee price for optimum cost.
Details
This function is helpful to determine if your product is elastic or not based on a linear price response function.
if product demand is
not linear to price, try using the single product optimization function instead. The price elasticity of demand
which is often shortened to demand elasticity
is defined to be the percentage change in quantity demanded, q, divided by the percentage change in price, p.
When |E| > 1, we say the good is price elastic.In this case,
change in price, there is a greater than 1
change in quantity demanded.In this case, management should decrease price to have a higher revenue.
When |E| < 1, we say the good is price inelastic.In this case,
for a 1
in quantity demanded.In this case, management should increase price to have a higher revenue.
When |E| = 1, we say the good is price unit elastic.In this case,
and so, for a 1
there is also an 1
This is the optimal price which means it maximizes revenue.